@@ -1,4 +1,5 @@
 # encoding: utf-8
+# frozen_string_literal: true
 # 
 # = Mail Envelope
 # 
@@ -11,12 +12,7 @@ module Mail
   class Envelope < StructuredField
     
     def initialize(*args)
-      super(FIELD_NAME, strip_field(FIELD_NAME, args.last))
-    end
-    
-    def tree
-      @element ||= Mail::EnvelopeFromElement.new(value)
-      @tree ||= @element.tree
+      super(FIELD_NAME, args.last.to_s)
     end
     
     def element
