@@ -1,4 +1,5 @@
 # encoding: utf-8
+# frozen_string_literal: true
 # 
 # 
 # 
@@ -12,13 +13,13 @@ module Mail
       self.charset = charset
       value = '7bit' if value.to_s =~ /7-?bits?/i
       value = '8bit' if value.to_s =~ /8-?bits?/i
-      super(CAPITALIZED_FIELD, strip_field(FIELD_NAME, value), charset)
+      super(CAPITALIZED_FIELD, value, charset)
       self.parse
       self
     end
     
     def parse(val = value)
-      unless val.blank?
+      unless Utilities.blank?(val)
         @element = Mail::ContentTransferEncodingElement.new(val)
       end
     end
