@@ -1,4 +1,5 @@
 # encoding: utf-8
+# frozen_string_literal: true
 module Mail
   
   # Provides access to a header object.
@@ -49,13 +50,14 @@ module Mail
     # me the example so we can fix it.
     def initialize(header_text = nil, charset = nil)
       @charset = charset
-      self.raw_source = header_text.to_crlf.lstrip
+      self.raw_source = header_text
       split_header if header_text
     end
 
     def initialize_copy(original)
       super
       @fields = @fields.dup
+      @fields.map!(&:dup)
     end
     
     # The preserved raw source of the header as you passed it in, untouched
@@ -91,14 +93,15 @@ module Mail
     #  h.fields = ['From: mikel@me.com', 'To: bob@you.com']
     def fields=(unfolded_fields)
       @fields = Mail::FieldList.new
-      warn "Warning: more than #{self.class.maximum_amount} header fields only using the first #{self.class.maximum_amount}" if unfolded_fields.length > self.class.maximum_amount
+      Kernel.warn "WARNING: More than #{self.class.maximum_amount} header fields; only using the first #{self.class.maximum_amount} and ignoring the rest" if unfolded_fields.length > self.class.maximum_amount
       unfolded_fields[0..(self.class.maximum_amount-1)].each do |field|
 
-        field = Field.new(field, nil, charset)
-        if limited_field?(field.name) && (selected = select_field_for(field.name)) && selected.any? 
-          selected.first.update(field.name, field.value)
-        else
-          @fields << field
+        if field = Field.parse(field, charset)
+          if limited_field?(field.name) && (selected = select_field_for(field.name)) && selected.any?
+            selected.first.update(field.name, field.value)
+          else
+            @fields << field
+          end
         end
       end
 
@@ -136,7 +139,7 @@ module Mail
       case
       when selected.length > 1
         selected.map { |f| f }
-      when !selected.blank?
+      when !Utilities.blank?(selected)
         selected.first
       else
         nil
@@ -166,11 +169,11 @@ module Mail
       
       case
       # User wants to delete the field
-      when !selected.blank? && value == nil
+      when !Utilities.blank?(selected) && value == nil
         fields.delete_if { |f| selected.include?(f) }
         
       # User wants to change the field
-      when !selected.blank? && limited_field?(fn)
+      when !Utilities.blank?(selected) && limited_field?(fn)
         selected.first.update(fn, value)
         
       # User wants to create the field
@@ -204,7 +207,7 @@ module Mail
                            content-id content-disposition content-location]
 
     def encoded
-      buffer = ''
+      buffer = String.new
       buffer.force_encoding('us-ascii') if buffer.respond_to?(:force_encoding)
       fields.each do |field|
         buffer << field.encoded
@@ -247,7 +250,7 @@ module Mail
     private
     
     def raw_source=(val)
-      @raw_source = val
+      @raw_source = ::Mail::Utilities.to_crlf(val).lstrip
     end
     
     # Splits an unfolded and line break cleaned header into individual field
