@@ -11,6 +11,22 @@ describe Mail::Encodings::UnixToUnix do
     Mail::Encodings::UnixToUnix.encode(str)
   end
 
+  it "is registered as uuencode" do
+    expect(Mail::Encodings.get_encoding('uuencode')).to eq(Mail::Encodings::UnixToUnix)
+  end
+
+  it "is registered as x-uuencode" do
+    expect(Mail::Encodings.get_encoding('x-uuencode')).to eq(Mail::Encodings::UnixToUnix)
+  end
+
+  it "is registered as x-uue" do
+    expect(Mail::Encodings.get_encoding('x-uue')).to eq(Mail::Encodings::UnixToUnix)
+  end
+
+  it "can transport itself" do
+    expect(Mail::Encodings::UnixToUnix.can_transport?(Mail::Encodings::UnixToUnix)).to be_truthy
+  end
+
   it "decodes" do
     text = strip_heredoc(<<-TEXT)
       begin 644 Happy.txt
