@@ -27,19 +27,13 @@ describe Mail::BccField do
   describe "initialization" do
 
     it "should initialize" do
-      expect { Mail::BccField.new("Bcc: Mikel") }.not_to raise_error
+      expect { Mail::BccField.new("Mikel") }.not_to raise_error
     end
 
     it "should mix in the CommonAddress module" do
       expect(Mail::BccField.included_modules).to include(Mail::CommonAddress) 
     end
 
-    it "should accept a string with the field name" do
-      t = Mail::BccField.new('Bcc: Mikel Lindsaar <mikel@test.lindsaar.net>, "Bob Smith" <bob@me.com>')
-      expect(t.name).to eq 'Bcc'
-      expect(t.value).to eq 'Mikel Lindsaar <mikel@test.lindsaar.net>, "Bob Smith" <bob@me.com>'
-    end
-
     it "should accept a string without the field name" do
       t = Mail::BccField.new('Mikel Lindsaar <mikel@test.lindsaar.net>, "Bob Smith" <bob@me.com>')
       expect(t.name).to eq 'Bcc'
