@@ -1,4 +1,5 @@
 # encoding: utf-8
+# frozen_string_literal: true
 require 'spec_helper'
 
 describe Mail::DateField do
@@ -34,13 +35,6 @@ describe Mail::DateField do
       expect(Mail::DateField.included_modules).to include(Mail::CommonDate) 
     end
 
-    it "should accept a string with the field name" do
-      t = Mail::DateField.new('Date: 12 Aug 2009 00:00:02 GMT')
-      expect(t.name).to eq 'Date'
-      expect(t.value).to eq 'Wed, 12 Aug 2009 00:00:02 +0000'
-      expect(t.date_time).to eq ::DateTime.parse('12 Aug 2009 00:00:02 GMT')
-    end
-
     it "should accept a string without the field name" do
       t = Mail::DateField.new('12 Aug 2009 00:00:02 GMT')
       expect(t.name).to eq 'Date'
