@@ -1,4 +1,5 @@
 # encoding: utf-8
+# frozen_string_literal: true
 require 'spec_helper'
 # 3.6.4. Identification fields
 #  
@@ -60,13 +61,6 @@ describe Mail::MessageIdField do
       expect { Mail::MessageIdField.new("<1234@test.lindsaar.net>") }.not_to raise_error
     end
 
-    it "should accept a string with the field name" do
-      m = Mail::MessageIdField.new('Message-ID: <1234@test.lindsaar.net>')
-      expect(m.name).to eq 'Message-ID'
-      expect(m.value).to eq '<1234@test.lindsaar.net>'
-      expect(m.message_id).to eq '1234@test.lindsaar.net'
-    end
-
     it "should accept a string without the field name" do
       m = Mail::MessageIdField.new('<1234@test.lindsaar.net>')
       expect(m.name).to eq 'Message-ID'
@@ -127,7 +121,7 @@ describe Mail::MessageIdField do
   describe "generating a message id" do
     it "should generate a message ID if it has no value" do
       m = Mail::MessageIdField.new
-      expect(m.message_id).not_to be_blank
+      expect(Mail::Utilities.blank?(m.message_id)).not_to be_truthy
     end
     
     it "should generate a random message ID" do
