@@ -10,19 +10,13 @@ describe Mail::ReplyToField do
   describe "initialization" do
 
     it "should initialize" do
-      expect { Mail::ReplyToField.new("Reply-To: Mikel") }.not_to raise_error
+      expect { Mail::ReplyToField.new("Mikel") }.not_to raise_error
     end
 
     it "should mix in the CommonAddress module" do
       expect(Mail::ReplyToField.included_modules).to include(Mail::CommonAddress) 
     end
 
-    it "should accept a string with the field name" do
-      t = Mail::ReplyToField.new('Reply-To: Mikel Lindsaar <mikel@test.lindsaar.net>, "Bob Smith" <bob@me.com>')
-      expect(t.name).to eq 'Reply-To'
-      expect(t.value).to eq 'Mikel Lindsaar <mikel@test.lindsaar.net>, "Bob Smith" <bob@me.com>'
-    end
-
     it "should accept a string without the field name" do
       t = Mail::ReplyToField.new('Mikel Lindsaar <mikel@test.lindsaar.net>, "Bob Smith" <bob@me.com>')
       expect(t.name).to eq 'Reply-To'
