@@ -18,8 +18,8 @@ describe "Utilities Module" do
       end
 
       it "should work with mb_chars" do
-        expect(token_safe?('.abc'.mb_chars)).to be_truthy
-        expect(token_safe?('?=abc'.mb_chars)).to be_falsey
+        expect(token_safe?(Mail::Multibyte.mb_chars('.abc'))).to be_truthy
+        expect(token_safe?(Mail::Multibyte.mb_chars('?=abc'))).to be_falsey
       end
     end
 
@@ -33,8 +33,8 @@ describe "Utilities Module" do
       end
 
       it "should work with mb_chars" do
-        expect(quote_token('.abc'.mb_chars)).to eq '.abc'
-        expect(quote_token('?=abc'.mb_chars)).to eq '"?=abc"'
+        expect(quote_token(Mail::Multibyte.mb_chars('.abc'))).to eq '.abc'
+        expect(quote_token(Mail::Multibyte.mb_chars('?=abc'))).to eq '"?=abc"'
       end
     end
 
@@ -52,8 +52,8 @@ describe "Utilities Module" do
       end
 
       it "should work with mb_chars" do
-        expect(atom_safe?('?=abc'.mb_chars)).to be_truthy
-        expect(atom_safe?('.abc'.mb_chars)).to be_falsey
+        expect(atom_safe?(Mail::Multibyte.mb_chars('?=abc'))).to be_truthy
+        expect(atom_safe?(Mail::Multibyte.mb_chars('.abc'))).to be_falsey
       end
     end
 
@@ -67,21 +67,15 @@ describe "Utilities Module" do
       end
 
       it "should work with mb_chars" do
-        expect(quote_atom('?=abc'.mb_chars)).to eq '?=abc'
-        expect(quote_atom('.abc'.mb_chars)).to eq '".abc"'
+        expect(quote_atom(Mail::Multibyte.mb_chars('?=abc'))).to eq '?=abc'
+        expect(quote_atom(Mail::Multibyte.mb_chars('.abc'))).to eq '".abc"'
       end
 
-      it "should work with mb_chars" do
-        expect(quote_atom('?=abc'.mb_chars)).to eq '?=abc'
-        expect(quote_atom('.abc'.mb_chars)).to eq '".abc"'
-      end
-
-      it "should quote white space" do
-        expect(quote_atom('ab abc'.mb_chars)).to eq '"ab abc"'
-        expect(quote_atom("a\sb\ta\r\nbc".mb_chars)).to eq %{"a\sb\ta\r\nbc"}
+      it "should quote mb_chars white space" do
+        expect(quote_atom(Mail::Multibyte.mb_chars('ab abc'))).to eq '"ab abc"'
+        expect(quote_atom(Mail::Multibyte.mb_chars("a\sb\ta\r\nbc"))).to eq %{"a\sb\ta\r\nbc"}
       end
     end
-
   end
 
   describe "quoting phrases" do
@@ -150,18 +144,17 @@ describe "Utilities Module" do
       expect(unparen(test)).to eq result
     end
 
-    it "should work using ActiveSupport mb_chars" do
-      test = '(This is a string)'.mb_chars
+    it "should work using Multibyte.mb_chars" do
+      test = Mail::Multibyte.mb_chars('(This is a string)')
       result = 'This is a string'
       expect(unparen(test)).to eq result
     end
 
-    it "should work without parens using ActiveSupport mb_chars" do
-      test = 'This is a string'.mb_chars
+    it "should work without parens using Multibyte.mb_chars" do
+      test = Mail::Multibyte.mb_chars('This is a string')
       result = 'This is a string'
       expect(unparen(test)).to eq result
     end
-
   end
 
   describe "unescaping brackets" do
@@ -178,18 +171,17 @@ describe "Utilities Module" do
       expect(unbracket(test)).to eq result
     end
 
-    it "should work using ActiveSupport mb_chars" do
-      test = '<This is a string>'.mb_chars
+    it "should work using Multibyte.mb_chars" do
+      test = Mail::Multibyte.mb_chars('<This is a string>')
       result = 'This is a string'
       expect(unbracket(test)).to eq result
     end
 
-    it "should work without parens using ActiveSupport mb_chars" do
-      test = 'This is a string'.mb_chars
+    it "should work without parens using Multibyte.mb_chars" do
+      test = Mail::Multibyte.mb_chars('This is a string')
       result = 'This is a string'
       expect(unbracket(test)).to eq(result)
     end
-
   end
 
   describe "quoting phrases" do
@@ -244,6 +236,23 @@ describe "Utilities Module" do
     end
   end
 
+  describe "unescaping phrases" do
+    it "should not modify a string with no backslashes" do
+      expect(unescape('This is a string')).to eq 'This is a string'
+    end
+
+    it "should not modify a quoted string with no backslashes" do
+      expect(unescape('"This is a string"')).to eq '"This is a string"'
+    end
+
+    it "should remove backslash escaping from a string" do
+      expect(unescape('This is \"a string\"')).to eq 'This is "a string"'
+    end
+
+    it "should remove backslash escaping from a quoted string" do
+      expect(unescape('"This is \"a string\""')).to eq '"This is "a string""'
+    end
+  end
 
   describe "parenthesizing phrases" do
     it "should parenthesize a phrase" do
@@ -430,152 +439,92 @@ describe "Utilities Module" do
   end
 
   describe "to_lf" do
-    it "should change a single CR to LF" do
+    it "converts single CR" do
       expect(Mail::Utilities.to_lf("\r")).to eq "\n"
     end
 
-    it "should change multiple LF to CRLF" do
+    it "converts multiple CR" do
       expect(Mail::Utilities.to_lf("\r\r")).to eq "\n\n"
     end
 
-    it "should change a single CRLF to LF" do
+    it "converts single CRLF" do
       expect(Mail::Utilities.to_lf("\r\n")).to eq "\n"
     end
 
-    it "should change multiple CR to LF" do
+    it "converts multiple CRLF" do
       expect(Mail::Utilities.to_lf("\r\n\r\n")).to eq "\n\n"
     end
 
-    it "should not change LF" do
-      expect(Mail::Utilities.to_lf("\n")).to eq "\n"
-    end
-
-    it "should not change multiple CRLF" do
+    it "leaves LF intact" do
       expect(Mail::Utilities.to_lf("\n\n")).to eq "\n\n"
     end
 
-    it "should handle a mix" do
+    it "converts mixed line endings" do
       expect(Mail::Utilities.to_lf("\r \n\r\n")).to eq "\n \n\n"
     end
 
-    if defined?(Encoding)
-      it "should not change the encoding of the string" do
-        saved_default_internal = Encoding.default_internal
-        Encoding.default_internal = "UTF-8"
-        ascii_string = "abcd".dup.force_encoding("ASCII-8BIT")
-        expect(Mail::Utilities.to_lf(ascii_string).encoding).to eq(Encoding::ASCII_8BIT)
-        Encoding.default_internal = saved_default_internal
-      end
+    it "should handle japanese characters" do
+      string = "\343\201\202\343\201\210\343\201\206\343\201\210\343\201\212\r\n\r\n\343\201\213\343\201\215\343\201\217\343\201\221\343\201\223\r\n\r\n\343\201\225\343\201\227\343\201\244\343\201\233\343\201\235\r\n\r\n"
+      expect(Mail::Utilities.binary_unsafe_to_lf(string)).to eq "\343\201\202\343\201\210\343\201\206\343\201\210\343\201\212\n\n\343\201\213\343\201\215\343\201\217\343\201\221\343\201\223\n\n\343\201\225\343\201\227\343\201\244\343\201\233\343\201\235\n\n"
     end
 
-    describe "to_lf method on String" do
-      it "should leave lf as lf" do
-        expect(Mail::Utilities.to_lf("\n")).to eq "\n"
-      end
-
-      it "should clean just cr to lf" do
-        expect(Mail::Utilities.to_lf("\r")).to eq "\n"
-      end
-
-      it "should leave crlf as lf" do
-        expect(Mail::Utilities.to_lf("\r\n")).to eq "\n"
-      end
-
-      it "should handle japanese characters" do
-        string = "\343\201\202\343\201\210\343\201\206\343\201\210\343\201\212\r\n\r\n\343\201\213\343\201\215\343\201\217\343\201\221\343\201\223\r\n\r\n\343\201\225\343\201\227\343\201\244\343\201\233\343\201\235\r\n\r\n"
-        expect(Mail::Utilities.to_lf(string)).to eq "\343\201\202\343\201\210\343\201\206\343\201\210\343\201\212\n\n\343\201\213\343\201\215\343\201\217\343\201\221\343\201\223\n\n\343\201\225\343\201\227\343\201\244\343\201\233\343\201\235\n\n"
-      end
-    end
-
-    describe "methods on NilClass" do
-      it "should return empty string on to_lf" do
+    describe "on NilClass" do
+      it "returns an empty string" do
         expect(Mail::Utilities.to_lf(nil)).to eq ''
       end
     end
 
-    describe "methods on subclass" do
-      it "should return String not subclass" do
+    describe "on String subclasses" do
+      it "returns Strings" do
         klass = Class.new(String)
         string = klass.new('')
         expect(Mail::Utilities.to_lf(string)).to be_an_instance_of(String)
       end
     end
-
   end
 
   describe "to_crlf" do
-
-    describe "to_crlf method on String" do
-      it "should clean just lf to crlf" do
-        expect(Mail::Utilities.to_crlf("\n")).to eq "\r\n"
-      end
-
-      it "should clean just cr to crlf" do
-        expect(Mail::Utilities.to_crlf("\r")).to eq "\r\n"
-      end
-
-      it "should leave crlf as crlf" do
-        expect(Mail::Utilities.to_crlf("\r\n")).to eq "\r\n"
-      end
-
-      it "should handle japanese characters" do
-        string = "\343\201\202\343\201\210\343\201\206\343\201\210\343\201\212\r\n\r\n\343\201\213\343\201\215\343\201\217\343\201\221\343\201\223\r\n\r\n\343\201\225\343\201\227\343\201\244\343\201\233\343\201\235\r\n\r\n"
-        expect(Mail::Utilities.to_crlf(string)).to eq "\343\201\202\343\201\210\343\201\206\343\201\210\343\201\212\r\n\r\n\343\201\213\343\201\215\343\201\217\343\201\221\343\201\223\r\n\r\n\343\201\225\343\201\227\343\201\244\343\201\233\343\201\235\r\n\r\n"
-      end
-
-      if defined?(Encoding)
-        it "should not change the encoding of the string" do
-          saved_default_internal = Encoding.default_internal
-          Encoding.default_internal = "UTF-8"
-          ascii_string = "abcd".dup.force_encoding("ASCII-8BIT")
-          expect(Mail::Utilities.to_crlf(ascii_string).encoding).to eq(Encoding::ASCII_8BIT)
-          Encoding.default_internal = saved_default_internal
-        end
-      end
-
+    it "converts single LF" do
+      expect(Mail::Utilities.to_crlf("\n")).to eq "\r\n"
     end
 
-    describe "methods on NilClass" do
-      it "should return empty string on to_crlf" do
+    it "converts multiple LF" do
+      expect(Mail::Utilities.to_crlf("\n\n")).to eq "\r\n\r\n"
+    end
+
+    it "converts single CR" do
+      expect(Mail::Utilities.to_crlf("\r")).to eq "\r\n"
+    end
+
+    it "preserves single CRLF" do
+      expect(Mail::Utilities.to_crlf("\r\n")).to eq "\r\n"
+    end
+
+    it "preserves multiple CRLF" do
+      expect(Mail::Utilities.to_crlf("\r\n\r\n")).to eq "\r\n\r\n"
+    end
+
+    it "converts mixed line endings" do
+      expect(Mail::Utilities.to_crlf("\r \n\r\n")).to eq "\r\n \r\n\r\n"
+    end
+
+    it "should handle japanese characters" do
+      string = "\343\201\202\343\201\210\343\201\206\343\201\210\343\201\212\r\n\r\n\343\201\213\343\201\215\343\201\217\343\201\221\343\201\223\r\n\r\n\343\201\225\343\201\227\343\201\244\343\201\233\343\201\235\r\n\r\n"
+      expect(Mail::Utilities.binary_unsafe_to_crlf(string)).to eq "\343\201\202\343\201\210\343\201\206\343\201\210\343\201\212\r\n\r\n\343\201\213\343\201\215\343\201\217\343\201\221\343\201\223\r\n\r\n\343\201\225\343\201\227\343\201\244\343\201\233\343\201\235\r\n\r\n"
+    end
+
+    describe "on NilClass" do
+      it "returns an empty string" do
         expect(Mail::Utilities.to_crlf(nil)).to eq ''
       end
     end
 
-    describe "methods on subclass" do
-      it "should return String not subclass" do
+    describe "on String subclasses" do
+      it "returns Strings" do
         klass = Class.new(String)
         string = klass.new('')
         expect(Mail::Utilities.to_crlf(string)).to be_an_instance_of(String)
       end
     end
-
-    describe "to_crlf" do
-
-      it "should change a single LF to CRLF" do
-        expect(Mail::Utilities.to_crlf("\n")).to eq "\r\n"
-      end
-
-      it "should change multiple LF to CRLF" do
-        expect(Mail::Utilities.to_crlf("\n\n")).to eq "\r\n\r\n"
-      end
-
-      it "should change a single CR to CRLF" do
-        expect(Mail::Utilities.to_crlf("\r")).to eq "\r\n"
-      end
-
-      it "should not change CRLF" do
-        expect(Mail::Utilities.to_crlf("\r\n")).to eq "\r\n"
-      end
-
-      it "should not change multiple CRLF" do
-        expect(Mail::Utilities.to_crlf("\r\n\r\n")).to eq "\r\n\r\n"
-      end
-
-      it "should handle a mix" do
-        expect(Mail::Utilities.to_crlf("\r \n\r\n")).to eq "\r\n \r\n\r\n"
-      end
-    end
-
   end
-
 end
